# -*- coding: utf-8 -*-

class Ihoutrpg < DiceBot

=begin

  ダイスボットバージョン: 1.0.0
  言語: 日本語(Japanese)
  ルール名:
    剣の街の異邦人TRPG

    版数:初版
    ISBN-13: ISBN978-4-04-072006-7
    エラッタ:未適用

  サプリメント:
    未適用

  販売/著作:
    KADOKAWA
    F.E.A.R.
    大畑顕
    エクスペリエンス

  ルール公式サポートサイト:
    http://www.fear.co.jp/ihoutrpg/

  ダイスボット製作:
    saronpasu

=end

  def initialize
    super
    @sendMode = 2
    @sortType = 1
    @d66Type = 1
    @fractionType = "omit"
  end

  def gameName
    '剣の街の異邦人TRPG'
  end

  def gameType
    "Ihoutrpg"
  end

  def prefixs
    [
        '\d+SR.*',
        'LFT',
        'LTR',
        'LGL',
        'PNAMEA',
        'PNAMEB'
    ]
  end

  def getHelpMessage
    info = <<INFO_MESSAGE_TEXT
・判定　xSR or xSRy or xSR+y or xSR-y or xSR+y>=z
　x=ダイス数、y=修正値(省略可、±省略時は＋として扱う)、z=難易度(省略可)
　判定時はクリティカル、ファンブルの自動判定を行います。
　(クリティカル時の追加ダメージも表示されます)
・通常のnD6ではクリティカル、ファンブルの自動判定は行いません。
・D66ダイスあり
=======================
チャート類：
・特徴表　LFT
・転移表　LTR
・目的表　LGL
・パーティー名決定表Ａ　PNAMEA
・パーティー名決定表Ｂ　PNAMEB
INFO_MESSAGE_TEXT
  end

  def rollDiceCommand(command)
      debug('rollDiceCommand command', command)

      command = command.upcase

      result = ''

      result = checkRoll(command)
      return result unless(result.empty?)

      result = rollTableCommand(command)
      return result
  end

  def checkRoll(string)
      debug("checkRoll begin string", string)

      result = ''
      pattern = /^(\d+)SR(?:([\+\-])?(\d+))?(?:>=(\d+))?$/i
      return result unless(pattern =~ string)

      totalValue = 0

      diceCount = $1.to_i
      operator = $2 if $2
      modify = $3.to_i if $3
      difficulty = $4.to_i if $4

      if (operator && modify) then
          modify = operator == "+" ? modify : ( modify * -1)
      end

      dice, diceStr = roll(diceCount, 6)
      diceList = diceStr.split(/,/).collect{|i|i.to_i}.sort

      totalValue = modify ? (dice + modify) : dice
      operator = '+' if (operator.nil? && modify)

      result += "(#{string}) ＞ #{dice}#{diceList.to_s.gsub(/\s/,'')}#{operator}#{modify ? modify.abs : ''} ＞ #{totalValue}"

      # isCritical
      criticalResult = isCritical(diceList)
      result += " ＞ クリティカル(+#{criticalResult}D6)" if criticalResult

      # isFumble
      fumbleResult = isFumble(diceList, diceCount)
      result += ' ＞ ファンブル' if fumbleResult

      # isSuccess
      if (!(criticalResult || fumbleResult) && difficulty) then
          result += (totalValue >= difficulty) ? ' ＞ 成功' : ' ＞ 失敗'
      end

      return result
  end

  def isCritical(diceList)
      result = nil
      if (diceList.select{|i| i == 6 }.size >= 2) then
          result = diceList.select{|i| i == 6 }.size.to_s
      else
          result = false
      end
      return result
  end

  def isFumble(diceList, diceCount)
    (diceList.select{|i| i == 1 }.size >= diceCount)
  end

  def rollTableCommand(command)
      debug('rollTableCommand command', command)

      tableName = ''
      result = ''
      number = ''

      case command
      when 'LFT'
          # LifepathFeature(特徴表)
          tableName, result, number = choiceLifepathFeatureTable()
      when 'LTR'
          # LifePathTranfer(転移表)
          tableName, result, number = choiceLifepathTransferTable()
      when 'LGL'
          # LifepathGoal(目的表)
          tableName, result, number = choiceLifepathGoalTable()
      when 'PNAMEA'
          # PartyNameA(パーティ名決定表Ａ)
          tableName, result, number = choicePartyNameATable()
      when 'PNAMEB'
          # PartyNameB(パーティー名決定表Ｂ)
          tableName, result, number = choicePartyNameBTable()
      else
          debug('rollDiceCommand commandNOT matched:', command)
          return
      end

      text = "#{tableName}(#{number}) ＞ #{result}"
      return text
  end

  def choiceLifepathFeatureTable()

      # reference from P.126
      tableName='特徴表'

      table = [
          # 0
          # "任意"+
          # "ＧＭと相談し、好きな特徴を設定すること。"+
          # "一般スキル:任意の一般スキルを１レベル分取得",
          # 11-12
          "危機一髪\n"+
          "あなたは危機的な目にあった。だが、今でも危険な状況に変わりはない。危険は常に、あなたにつきまとっている。\n"+
          "一般スキル：《シックスセンス》(P 180)",
          "危機一髪\n"+
          "あなたは危機的な目にあった。だが、今でも危険な状況に変わりはない。危険は常に、あなたにつきまとっている。\n"+
          "一般スキル：《シックスセンス》(P 180)",
          # 13-14
          "孤立無援\n"+
          "あなたは孤立していた。いっそどこか別の世界にでも行ってしまいたい状況だった。\n"+
          "一般スキル:《ビジランテ》(P 181)",
          "孤立無援\n"+
          "あなたは孤立していた。いっそどこか別の世界にでも行ってしまいたい状況だった。\n"+
          "一般スキル:《ビジランテ》(P 181)",
          # 15-16
          "呼ぶ声\n"+
          "どこからともなく声が聞こえる。あなたはそんな体験をしていた。その声にはなぜか抗いがたい魅力を感じていた。\n"+
          "一般スキル:《アイデンティファイ》(P 178)",
          "呼ぶ声\n"+
          "どこからともなく声が聞こえる。あなたはそんな体験をしていた。その声にはなぜか抗いがたい魅力を感じていた。\n"+
          "一般スキル:《アイデンティファイ》(P 178)",
          # 21-22
          "理不尽\n"+
          "この世は理不尽ばかりだ。いっそファンタジー世界にでも行けば楽なのかもしれない。\n"+
          "一般スキル:《カルチャー:エスカリオ》(P 178)",
          "理不尽\n"+
          "この世は理不尽ばかりだ。いっそファンタジー世界にでも行けば楽なのかもしれない。\n"+
          "一般スキル:《カルチャー:エスカリオ》(P 178)",
          # 23-24
          "逃亡\n"+
          "あなたは逃げ出したい。あるいは逃げだした。いっそ知らない世界にでも行ければいいのに。\n"+
          "一般スキル:《サーチリスク》(P 180)",
          "逃亡\n"+
          "あなたは逃げ出したい。あるいは逃げだした。いっそ知らない世界にでも行ければいいのに。\n"+
          "一般スキル:《サーチリスク》(P 180)",
          # 25-26
          "諦観\n"+
          "あなたは日常にあきらめていた。立場に？　将来に？　何も代わり映えしない日常に？　どうせ自分が何をしても、何も変わらないのだ。\n"+
          "一般スキル:《インサイト》(P 178)",
          "諦観\n"+
          "あなたは日常にあきらめていた。立場に？　将来に？　何も代わり映えしない日常に？　どうせ自分が何をしても、何も変わらないのだ。\n"+
          "一般スキル:《インサイト》(P 178)",
          # 31-32
          "屈辱\n"+
          "あなたは辱めを受けていた。会社で？　学校で？　ご近所で？　ああ、いっそ誰も知らない世界に行ってしまいたいほどだ。\n"+
          "一般スキル:《エンラージリミット》(P 179)",
          "屈辱\n"+
          "あなたは辱めを受けていた。会社で？　学校で？　ご近所で？　ああ、いっそ誰も知らない世界に行ってしまいたいほどだ。\n"+
          "一般スキル:《エンラージリミット》(P 179)",
          # 33-34
          "称号\n"+
          "あなたには「選ばれた」という。何に？　何のために？　疑問は尽きず、答えは何ひとつ用意されていなかった。\n"+
          "一般スキル:《ブラフ》(P 182)",
          "称号\n"+
          "あなたには「選ばれた」という。何に？　何のために？　疑問は尽きず、答えは何ひとつ用意されていなかった。\n"+
          "一般スキル:《ブラフ》(P 182)",
          # 35-36
          "啓示\n"+
          "あなたの頭の中に突然何かが閃いた。急に示された内容は信じがたいものだった。そして、自身の転機が迫っていることにも気付いていた。\n"+
          "一般スキル:《オピニオン》(P 179)",
          "啓示\n"+
          "あなたの頭の中に突然何かが閃いた。急に示された内容は信じがたいものだった。そして、自身の転機が迫っていることにも気付いていた。\n"+
          "一般スキル:《オピニオン》(P 179)",
          # 41-42
          "想定外\n"+
          "世の中に想定外のことなどない。決められた、あるいは予想通りに進む人生に、しかしそれは起こってしまった。\n"+
          "一般スキル:《カルチャー:地球》(P 179)",
          "想定外\n"+
          "世の中に想定外のことなどない。決められた、あるいは予想通りに進む人生に、しかしそれは起こってしまった。\n"+
          "一般スキル:《カルチャー:地球》(P 179)",
          # 43-44
          "自由\n"+
          "あなたは自由がほしかった。自分をつなぐこの世界から逃げだしたいほどだった。\n"+
          "一般スキル:《トラッキング》(P 181)",
          "自由\n"+
          "あなたは自由がほしかった。自分をつなぐこの世界から逃げだしたいほどだった。\n"+
          "一般スキル:《トラッキング》(P 181)",
          # 45-46
          "枷\n"+
          "あなたには枷が掛けられている。あなたにとって、あるいは周囲の人にとってそれは重要なものだった。今となっては無意味なことだ。\n"+
          "一般スキル:《デストロイヤー》(P 180)",
          "枷\n"+
          "あなたには枷が掛けられている。あなたにとって、あるいは周囲の人にとってそれは重要なものだった。今となっては無意味なことだ。\n"+
          "一般スキル:《デストロイヤー》(P 180)",
          # 51-52
          "無理解\n"+
          "誰もあなたのことを理解してくれない。この世界に自分の理解者はいないのだろうか？\n"+
          "一般スキル:《ヒストリー》(P 181)",
          "無理解\n"+
          "誰もあなたのことを理解してくれない。この世界に自分の理解者はいないのだろうか？\n"+
          "一般スキル:《ヒストリー》(P 181)",
          # 53-54
          "取引\n"+
          "あなたは、その取引に応じてしまった。それはあなたにとって、思いもよらぬ結果を生み出した。\n"+
          "一般スキル:《ストリートワイズ》(P 180)",
          "取引\n"+
          "あなたは、その取引に応じてしまった。それはあなたにとって、思いもよらぬ結果を生み出した。\n"+
          "一般スキル:《ストリートワイズ》(P 180)",
          # 55-56
          "罠\n"+
          "あなたは罠にかけられた。もうこの世界に味方はいない。いっそ別の世界にでも行きたい気分だ。\n"+
          "一般スキル:《リムーブトラップ》(P 183)",
          "罠\n"+
          "あなたは罠にかけられた。もうこの世界に味方はいない。いっそ別の世界にでも行きたい気分だ。\n"+
          "一般スキル:《リムーブトラップ》(P 183)",
          # 61-62
          "大義\n"+
          "あなたには果たすべき大義がある。しかし、現代地球では残念ながら果たせそうにないのが悩ましかった。\n"+
          "一般スキル:《マシンノウリッジ》(P 182)",
          "大義\n"+
          "あなたには果たすべき大義がある。しかし、現代地球では残念ながら果たせそうにないのが悩ましかった。\n"+
          "一般スキル:《マシンノウリッジ》(P 182)",
          # 63-64
          "裏切り\n"+
          "あなたは裏切られた。復讐したいが今は無理だ。それを成し遂げるために、キミは力を欲した。\n"+
          "一般スキル:《マジックノウリッジ》(P 182)",
          "裏切り\n"+
          "あなたは裏切られた。復讐したいが今は無理だ。それを成し遂げるために、キミは力を欲した。\n"+
          "一般スキル:《マジックノウリッジ》(P 182)",
          # 65-66
          "前知\n"+
          "あなたは何者かによって呼ばれているような気がした。今思えば、あれは何かの予兆だったのだろう。\n"+
          "一般スキル:《リサーチ》(P 183)",
          "前知\n"+
          "あなたは何者かによって呼ばれているような気がした。今思えば、あれは何かの予兆だったのだろう。\n"+
          "一般スキル:《リサーチ》(P 183)"
      ]

      result, number = get_table_by_d66(table)
      return tableName, result, number
  end

  def choiceLifepathTransferTable()

      # reference from P.127
      tableName='転移表'

      table = [
          # 0
          # "任意\n"+
          # "ＧＭと相談し、好きな転移を設定すること。",
          # 11-12
          "トラック\n"+
          "あなたは誰かに突き飛ばされ、トラックに轢かれそうになった。だが、死んだと思ったところで意識が途絶え、気がつくと知らない場所にいた。",
          "トラック\n"+
          "あなたは誰かに突き飛ばされ、トラックに轢かれそうになった。だが、死んだと思ったところで意識が途絶え、気がつくと知らない場所にいた。",
          # 13-14
          "銃声\n"+
          "誰かがあなたを盾にした、あるいはあなたが誰かをかばったか。あなたをめがけて銃声が響いた直後、なぜかあなたは元いたところと違う場所にいた。",
          "銃声\n"+
          "誰かがあなたを盾にした、あるいはあなたが誰かをかばったか。あなたをめがけて銃声が響いた直後、なぜかあなたは元いたところと違う場所にいた。",
          # 15-16
          "スマホ\n"+
          "あなたのスマートフォンに着信があった。あなたが通話ボタンを押した瞬間、スマートフォンが突然猛烈な光を放ち、光に飲み込まれたあなたは、知らない場所へと放り出された。",
          "スマホ\n"+
          "あなたのスマートフォンに着信があった。あなたが通話ボタンを押した瞬間、スマートフォンが突然猛烈な光を放ち、光に飲み込まれたあなたは、知らない場所へと放り出された。",
          # 21-22
          "夢\n"+
          "あなたは夢を見ていたはずだった。だが、目覚めたあなたの目の前には、夢とまったく同じ光景が広がっていた。",
          "夢\n"+
          "あなたは夢を見ていたはずだった。だが、目覚めたあなたの目の前には、夢とまったく同じ光景が広がっていた。",
          # 23-24
          "ゲーム\n"+
          "あなたは他人の機械を借りてゲームをしていた。ゲームを終えたあなたが見たものは、今までプレイしていたゲームと同じ光景であった。",
          "ゲーム\n"+
          "あなたは他人の機械を借りてゲームをしていた。ゲームを終えたあなたが見たものは、今までプレイしていたゲームと同じ光景であった。",
          # 25-26
          "霧\n"+
          "あなたは突然現れた濃い霧の中で迷ってしまった。どうにか霧を抜けたその先には、見知らぬ土地が広がっていた。",
          "霧\n"+
          "あなたは突然現れた濃い霧の中で迷ってしまった。どうにか霧を抜けたその先には、見知らぬ土地が広がっていた。",
          # 31-32
          "流星\n"+
          "あなたの知人が流星に「どこか別の場所に行きたい」と願い事をしていた。それを聞いた直後、気づけばあなたは知らない場所にたたずんでいた。",
          "流星\n"+
          "あなたの知人が流星に「どこか別の場所に行きたい」と願い事をしていた。それを聞いた直後、気づけばあなたは知らない場所にたたずんでいた。",
          # 33-34
          "穴\n"+
          "あなたが妙なところに空いた穴をのぞいたとき、誰かがあなたの背中を押した。長い穴を抜けたあなたは、やがて見知らぬ場所にたどり着いた。",
          "穴\n"+
          "あなたが妙なところに空いた穴をのぞいたとき、誰かがあなたの背中を押した。長い穴を抜けたあなたは、やがて見知らぬ場所にたどり着いた。",
          # 35-36
          "謎の声\n"+
          "あなたの頭に直接謎の声が響いた。その声はあなたを別人と誤解しているようだ。そして、気がつくと元いた所と違う場所にいた。",
          "謎の声\n"+
          "あなたの頭に直接謎の声が響いた。その声はあなたを別人と誤解しているようだ。そして、気がつくと元いた所と違う場所にいた。",
          # 41-42
          "階段\n"+
          "階段から落ちそうになった誰かを助けようとして、あなたが代わりに落ちてしまった。だが、気づけばあなたはまったく知らない場所にいた。",
          "階段\n"+
          "階段から落ちそうになった誰かを助けようとして、あなたが代わりに落ちてしまった。だが、気づけばあなたはまったく知らない場所にいた。",
          # 43-44
          "雷\n"+
          "落雷があなたを貫いたとき、あなたは死を覚悟した。しかし、あなたが意識を取り戻すと、なぜか先ほどとは違う、見知らぬ場所にいた。",
          "雷\n"+
          "落雷があなたを貫いたとき、あなたは死を覚悟した。しかし、あなたが意識を取り戻すと、なぜか先ほどとは違う、見知らぬ場所にいた。",
          # 45-46
          "老人\n"+
          "あなたの前に老人が現れた。老人はあなたを「選ばれし者よ」と呼び、消えた。周囲を見回したあなたは、そこが自分の知らない場所だと気づいた。",
          "老人\n"+
          "あなたの前に老人が現れた。老人はあなたを「選ばれし者よ」と呼び、消えた。周囲を見回したあなたは、そこが自分の知らない場所だと気づいた。",
          # 51-52
          "魔法陣\n"+
          "あなたの知人の周囲に、突然魔法陣のような模様が展開した。その模様に巻き込まれたあなたは、気がつくと見知らぬ場所にいた。",
          "魔法陣\n"+
          "あなたの知人の周囲に、突然魔法陣のような模様が展開した。その模様に巻き込まれたあなたは、気がつくと見知らぬ場所にいた。",
          # 53-54
          "映像\n"+
          "あなたが偶然見かけたインターネット上の動画。ディスプレイに吸い込まれたような感覚がした直後、あなたはなぜか知らない場所にいた。",
          "映像\n"+
          "あなたが偶然見かけたインターネット上の動画。ディスプレイに吸い込まれたような感覚がした直後、あなたはなぜか知らない場所にいた。",
          # 55-56
          "ドア\n"+
          "あなたは今までなかったところに扉があることに気付いた。あなたの目の前で扉が開き、引きずりこまれてしまったあなたは、見知らぬ場所に放り出されていた。",
          "ドア\n"+
          "あなたは今までなかったところに扉があることに気付いた。あなたの目の前で扉が開き、引きずりこまれてしまったあなたは、見知らぬ場所に放り出されていた。",
          # 61-62
          "妖精\n"+
          "あなたは羽のある小さな人間が飛ぶのを見かけた。ソレがあなたの周囲をくるりと回った直後、目の前の光景は変貌していた。",
          "妖精\n"+
          "あなたは羽のある小さな人間が飛ぶのを見かけた。ソレがあなたの周囲をくるりと回った直後、目の前の光景は変貌していた。",
          # 63-64
          "乗り物\n"+
          "あなたが車や列車、飛行機などに乗っている際に、突然視界が暗転した。気がつくと、あなたは見知らぬ場所にいた。",
          "乗り物\n"+
          "あなたが車や列車、飛行機などに乗っている際に、突然視界が暗転した。気がつくと、あなたは見知らぬ場所にいた。",
          # 65-66
          "不明\n"+
          "あなたが気がついたときには、すでにあなたは知らない場所にいた。どうしてそうなってしまったのか、いったい何が起こったかすら、あなたは覚えていない。",
          "不明\n"+
          "あなたが気がついたときには、すでにあなたは知らない場所にいた。どうしてそうなってしまったのか、いったい何が起こったかすら、あなたは覚えていない。"
      ]

      result, number = get_table_by_d66(table)
      return tableName, result, number
  end

  def choiceLifepathGoalTable()

      # reference from P.128
      tableName='目的表'

      table = [
          # 0
          # "任意\n"+
          # "ＧＭと相談し、任意の目的を設定すること。",
          # 11-12
          "大願成就\n"+
          "あなたはエスカリオで、大きな願いを果たさねばならなくなった。本意であれ不本意であれ、あなたはそれをかなえなければならない。",
          "大願成就\n"+
          "あなたはエスカリオで、大きな願いを果たさねばならなくなった。本意であれ不本意であれ、あなたはそれをかなえなければならない。",
          # 13-14
          "平和\n"+
          "あなたの目的を果たすには、エスカリオで平和を実現せねばならない。あなたはあなたの目的のため、平和を実現しようと動いている。",
          "平和\n"+
          "あなたの目的を果たすには、エスカリオで平和を実現せねばならない。あなたはあなたの目的のため、平和を実現しようと動いている。",
          # 15-16
          "希望\n"+
          "あなたの目的を果たすには、エスカリオで希望を実現せねばならない。その希望がどのようなものであれ、あなたはそれをかなえなければならない。",
          "希望\n"+
          "あなたの目的を果たすには、エスカリオで希望を実現せねばならない。その希望がどのようなものであれ、あなたはそれをかなえなければならない。",
          # 21-22
          "帰還\n"+
          "あなたはエスカリオから脱出し、元の世界へ帰還したいと思っている。その方法を探すために、あなたは冒険を選んだ。",
          "帰還\n"+
          "あなたはエスカリオから脱出し、元の世界へ帰還したいと思っている。その方法を探すために、あなたは冒険を選んだ。",
          # 23-24
          "居場所\n"+
          "あなたはエスカリオという世界で、居場所を得てしまった。どんな形で得たにせよ、それはあなたにとって重要な部分を占め始めている。",
          "居場所\n"+
          "あなたはエスカリオという世界で、居場所を得てしまった。どんな形で得たにせよ、それはあなたにとって重要な部分を占め始めている。",
          # 25-26
          "新目標\n"+
          "あなたはエスカリオに来てしまったせいで、新たな目標を得てしまった。たとえそれが不本意であったとしても、当面はそれを目指さねばならないだろう。",
          "新目標\n"+
          "あなたはエスカリオに来てしまったせいで、新たな目標を得てしまった。たとえそれが不本意であったとしても、当面はそれを目指さねばならないだろう。",
          # 31-32
          "回復\n"+
          "あなたはエスカリオに来ることで、失った何かを回復したいと思っている。物か、あるいは人なのか、あなたはそれを取り戻したいと願っている。",
          "回復\n"+
          "あなたはエスカリオに来ることで、失った何かを回復したいと思っている。物か、あるいは人なのか、あなたはそれを取り戻したいと願っている。",
          # 33-34
          "栄光\n"+
          "あなたはエスカリオで、栄光をつかむ必要に迫られた。栄光をつかみ取ることで、あなたは何を得るのだろう。",
          "栄光\n"+
          "あなたはエスカリオで、栄光をつかむ必要に迫られた。栄光をつかみ取ることで、あなたは何を得るのだろう。",
          # 35-36
          "スター\n"+
          "あなたはエスカリオの”星”となる。”星”の示す意味は、果たして比喩か、それとも本当の天体となるのか。いずれにせよ、あなたはそれを目指そうと考えている。",
          "スター\n"+
          "あなたはエスカリオの”星”となる。”星”の示す意味は、果たして比喩か、それとも本当の天体となるのか。いずれにせよ、あなたはそれを目指そうと考えている。",
          # 41-42
          "キラキラ\n"+
          "あなたはエスカリオでキラキラしたいと思っている。たとえ異世界であったとしても、あなたは自分らしくキラキラし続けていたいのだ。",
          "キラキラ\n"+
          "あなたはエスカリオでキラキラしたいと思っている。たとえ異世界であったとしても、あなたは自分らしくキラキラし続けていたいのだ。",
          # 43-44
          "真実\n"+
          "あなたはエスカリオでとある真実を知ってしまった。真実の内容を、あなたはまだ誰にも話していない。",
          "真実\n"+
          "あなたはエスカリオでとある真実を知ってしまった。真実の内容を、あなたはまだ誰にも話していない。",
          # 45-46
          "平穏\n"+
          "あなたはエスカリオで平穏を得たいと願っている。あなたは望む平穏を手にするために、あえて冒険に身を投じているのだ。",
          "平穏\n"+
          "あなたはエスカリオで平穏を得たいと願っている。あなたは望む平穏を手にするために、あえて冒険に身を投じているのだ。",
          # 51-52
          "征服\n"+
          "あなたは、エスカリオを征服するという野望を密かに持っている。何をもって征服とするかはさておき、あなたは着々とその準備を進めている。",
          "征服\n"+
          "あなたは、エスカリオを征服するという野望を密かに持っている。何をもって征服とするかはさておき、あなたは着々とその準備を進めている。",
          # 53-54
          "満腹\n"+
          "あなたはエスカリオで満腹になりたい。これは比喩でもよいし単純に十分に食事をするという意味でもよい。詳細はＧＭと相談の上、指示に従うこと。",
          "満腹\n"+
          "あなたはエスカリオで満腹になりたい。これは比喩でもよいし単純に十分に食事をするという意味でもよい。詳細はＧＭと相談の上、指示に従うこと。",
          # 55-56
          "尋ね人\n"+
          "あなたはエスカリオで人を探している。あなたと同じ異邦人か、エスカリオで出会った人なのか。あなたはその人を何としてでも見つけなければならない。",
          "尋ね人\n"+
          "あなたはエスカリオで人を探している。あなたと同じ異邦人か、エスカリオで出会った人なのか。あなたはその人を何としてでも見つけなければならない。",
          # 61-62
          "解呪\n"+
          "あなたはエスカリオで、呪いを解こうとしている。魔法があるこの世界ならば、かけられた呪いを解くことができるかもしれない。あなたは、その方法を探している。",
          "解呪\n"+
          "あなたはエスカリオで、呪いを解こうとしている。魔法があるこの世界ならば、かけられた呪いを解くことができるかもしれない。あなたは、その方法を探している。",
          # 63-64
          "契約\n"+
          "あなたは契約を交わしており、それを履行せねばならない。望むと望まざると関係なく、あなたは契約の下で動かなければならない。",
          "契約\n"+
          "あなたは契約を交わしており、それを履行せねばならない。望むと望まざると関係なく、あなたは契約の下で動かなければならない。",
          # 65-66
          "革命\n"+
          "あなたはエスカリオに革命を起こそうと思っている。それがどのような規模であれ、あなたはこの世界に何らかの影響をもたらそうとしている。",
          "革命\n"+
          "あなたはエスカリオに革命を起こそうと思っている。それがどのような規模であれ、あなたはこの世界に何らかの影響をもたらそうとしている。"
      ]

      result, number = get_table_by_d66(table)
      return tableName, result, number
  end

  def choicePartyNameATable()

      # reference from P.205
      tableName='パーティー名決定表Ａ'

      table = [
          # 1-1,   1-2,     1-3,     1-4,      1-5,    1-6
          "グレート", "マッド", "パワード", "クロック", "クール", "ホット",
          # 2-1,  2-2,      2-3,     2-4,       2-5,      2-6
          "ウッド", "ブロンズ", "アイアン", "シルバー", "ゴールド", "クリスタル",
          # 3-1,      3-2,         3-3,      3-4,        3-5,      3-6
          "勇猛(なる)", "華麗(なる)", "幸運(の)", "衝撃(の)", "究極(の)", "至高(の)",
          # 4-1,    4-2,     4-3,     4-4,     4-5,      4-6
          "風(の)", "雷(の)", "嵐(の)", "氷(の)", "炎(の)", "幻(の)",
          # 5-1,     5-2,     5-3,      5-4,     5-5,     5-6
          "無色(の)", "白(の)", "黒(の)", "赤(の)", "青(の)", "緑(の)",
          # 6-1,     6-2,     6-3,      6-4,     6-5,     6-6
          "太陽(の)", "月(の)", "星(の)", "暁(の)", "光(の)", "闇(の)"
      ]

      result, number = get_table_by_d66(table)
      return tableName, result, number
  end

  def choicePartyNameBTable()

      # reference from P.205
      tableName='パーティー名決定表Ｂ'

      table = [
          # 1-1,      1-2,   1-3,         1-4,       1-5,      1-6
          "クラッシャー", "デス", "ジャスティス", "フリーダム", "アルカナ", "ミラージュ",
          # 2-1,    2-2,      2-3,    2-4,    2-5,       2-6
          "トループ", "ランサー", "ナイツ", "クラン", "ブリゲイド", "レギオン",
          # 3-1,    3-2,       3-3,       3-4,        3-5,      3-6
          "ペガサス", "グリフォン", "ワイバーン", "ユニコーン", "ゴーレム", "フェニックス",
          # 4-1, 4-2,    4-3,   4-4,   4-5,  4-6
          "従者", "乙女", "射手", "騎士", "王", "魔王",
          # 5-1, 5-2,   5-3,  5-4,   5-5,   5-6
          "馬",  "蜘蛛", "鷹", "猟犬", "獅子", "竜",
          # 6-1, 6-2, 6-3,  6-4,  6-5,  6-6
          "剣",  "矢", "槍", "斧", "拳", "盾"
      ]

      result, number = get_table_by_d66(table)
      return tableName, result, number
  end

end
